@@ -159,22 +159,6 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertTrue(locality['los angeles'] > 3000)
         self.assertTrue(locality['beverly hills'] > 500)
 
-    def test_geopulse(self):
-        geopulse = self.factual.geopulse(point(34.06021, -118.41828))
-        income_only = geopulse.select('income')
-        all_results = geopulse.data()
-        income_results = income_only.data()
-        self.assertIn('demographics', all_results)
-        demographics = all_results['demographics']
-        self.assertIn('area_statistics', demographics)
-        area_statistics = demographics['area_statistics']
-        self.assertIn('commercial_residential', area_statistics)
-        commercial_residential = area_statistics['commercial_residential']
-        self.assertTrue(0 <= commercial_residential['business'] <= 100)
-        income_demographics = income_results['demographics']
-        self.assertEqual(1, len(income_demographics))
-        self.assertIn('income', income_demographics)
-
     def test_geocode(self):
         geocode = self.factual.geocode(point(34.058744, -118.416937))
         result = geocode.data()[0]
@@ -212,12 +196,17 @@ class FactualAPITestSuite(unittest.TestCase):
         response = flag.write()
         self.assertEqual('ok', response['status'])
 
+    def test_flag_preferred(self):
+        flag = self.factual.flag('us-sandbox', SANDBOX_UUID).duplicate(FACTUAL_UUID).user('python_driver_tester').debug(True)
+        response = flag.write()
+        self.assertEqual('ok', response['status'])
+
     def test_diffs(self):
-        diffs = self.factual.diffs('places-us', 1372694400000, 1372695300000).data()
+        diffs = self.factual.diffs('places-us', 1400788800000, 1400792400000).data()
         self.assertGreater(len(diffs), 0)
 
     def test_diffs_streaming(self):
-        diff_request = self.factual.diffs('places-us', 1372694400000, 1372695300000)
+        diff_request = self.factual.diffs('places-us', 1400788800000, 1400792400000)
         batch = diff_request.data()
         streamed = list(diff_request.stream())
         self.assertSequenceEqual(batch, streamed)
